pub struct InvokeDecisioning {
pub source: String,
pub correlation_id: Option<String>,
pub context: CurrentContext,
}Expand description
Event to trigger the decision-making phase.
This event initiates the decision process where the agent evaluates the current plan and history to decide on the next action.
Fields
source: Stringcorrelation_id: Option<String>context: CurrentContextThe current context as we work through our response.