Router

Struct Router 

pub struct Router { /* private fields */ }
Routes events to registered agents based on event type.

The Router maintains a mapping of event TypeIds to vectors of agents that should process those events. Multiple agents can be registered for the same event type.

Examples

use mojentic::router::Router;

let mut router = Router::new();
router.add_route::<MyEvent>(my_agent);

Implementations

Source

impl Router

pub fn new() -> Self

Create a new empty router

pub fn add_route<T: 'static>(&mut self, agent: Arc<dyn BaseAsyncAgent>)

Add a route mapping an event type to an agent

Arguments
  • agent - The agent to handle events of type T
pub fn get_agents(&self, type_id: TypeId) -> Vec<Arc<dyn BaseAsyncAgent>>

Get all agents registered for a specific event type

Arguments
  • type_id - The TypeId of the event type