TracerEvent

Trait TracerEvent 

pub trait TracerEvent: Send + Sync {
    // Required methods
    fn timestamp(&self) -> f64;
    fn correlation_id(&self) -> &str;
    fn source(&self) -> &str;
    fn printable_summary(&self) -> String;
}
Base trait for all tracer events

Tracer events are used to track system interactions for observability purposes. They are distinct from regular events which are used for agent communication.

Required Methods

fn timestamp(&self) -> f64

Get the timestamp when the event occurred

fn correlation_id(&self) -> &str

Get the correlation ID for tracing related events

fn source(&self) -> &str

Get the source of the event

fn printable_summary(&self) -> String

Get a formatted string summary of the event

Implementors