pub struct EventEmitter { /* private fields */ }Expand description
A simple event emitter that allows subscribing to and emitting events.
This implementation uses async channels to dispatch events to subscribers asynchronously without blocking the emitter.
Implementations
Sourceimpl EventEmitter
impl EventEmitter
Sourcepub async fn emit(&self, event: AnySolverEvent)
pub async fn emit(&self, event: AnySolverEvent)
Emit an event to all subscribers asynchronously.
Events are dispatched to subscribers without blocking the emitter.