pub struct InvokeToolCall {
pub source: String,
pub correlation_id: Option<String>,
pub context: CurrentContext,
pub thought: String,
pub action: NextAction,
pub tool: Arc<dyn LlmTool>,
pub tool_arguments: HashMap<String, Value>,
}Expand description
Event to trigger a tool invocation.
This event carries the information needed to execute a specific tool
with given arguments, along with the reasoning behind the decision.
Note: Cannot be cloned/serialized due to Arc
Fields
source: Stringcorrelation_id: Option<String>context: CurrentContextThe current context as we work through our response.
thought: StringThe reasoning behind the decision.
action: NextActionThe next action type.
tool: Arc<dyn LlmTool>The tool instance to invoke.
tool_arguments: HashMap<String, Value>Arguments to pass to the tool.