pub fn all_tools(task_list: Arc<Mutex<TaskList>>) -> Vec<Box<dyn LlmTool>>Expand description
Creates all task manager tools with a shared task list
Returns a vector of boxed tools ready to be used with the broker
Examples
ⓘ
use mojentic::llm::tools::ephemeral_task_manager::{TaskList, all_tools};
use std::sync::{Arc, Mutex};
let task_list = Arc::new(Mutex::new(TaskList::new()));
let tools = all_tools(task_list);